'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _common = require('../common');

var _common2 = _interopRequireDefault(_common);

var _default = require('../default');

var _default2 = _interopRequireDefault(_default);

var _path = require('path');

var _webpack = require('webpack');

var _webpack2 = _interopRequireDefault(_webpack);

var _webpackMerge = require('webpack-merge');

var _webpackMerge2 = _interopRequireDefault(_webpackMerge);

var _npmInstallWebpackPlugin = require('npm-install-webpack-plugin');

var _npmInstallWebpackPlugin2 = _interopRequireDefault(_npmInstallWebpackPlugin);

var _htmlWebpackPlugin = require('html-webpack-plugin');

var _htmlWebpackPlugin2 = _interopRequireDefault(_htmlWebpackPlugin);

var _autodllWebpackPlugin = require('autodll-webpack-plugin');

var _autodllWebpackPlugin2 = _interopRequireDefault(_autodllWebpackPlugin);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var getInitDevConfig = function getInitDevConfig(_ref) {
  var root = _ref.root,
      srcPath = _ref.srcPath,
      distPath = _ref.distPath,
      vendor = _ref.vendor,
      enableHTMLPlugin = _ref.enableHTMLPlugin,
      devServer = _ref.devServer;

  root = root || _default2.default.root;
  srcPath = srcPath || _default2.default.srcPath;
  distPath = distPath || _default2.default.distPath;
  enableHTMLPlugin = enableHTMLPlugin || _default2.default.enableHTMLPlugin;
  devServer = Object.assign({}, _default2.default.devServer, devServer);
  var config = (0, _webpackMerge2.default)(_common2.default, {
    //mode: 'development',
    context: (0, _path.resolve)(root, srcPath),
    entry: {
      app: './index.js'
    },
    output: {
      filename: '[name]-[id].js',
      path: (0, _path.resolve)(root, distPath)
    },
    devServer: devServer,
    module: {
      rules: [{
        test: /\.js$/,
        loader: 'babel-loader',
        exclude: /node_modules/
      }, {
        test: /\.css$/,
        exclude: /node_modules/,
        use: [{
          loader: 'style-loader',
          options: {
            sourceMap: true
          }
        }, {
          loader: 'css-loader',
          options: {
            importLoaders: 0,
            modules: true,
            localIdentName: '[name]_[local]'
          }
        }]
      }, {
        //引入的css包不使用css modules
        test: /(?=node_modules).*\.css$/,
        use: ['style-loader', 'css-loader']
      }, {
        test: /\.(jpe?g|png|gif|svg|woff|woff2|eot|otf|ttf)$/i,
        use: [{
          loader: 'file-loader',
          options: {
            name: '[path]/[name].[ext]'
          }
        }]
      }]
    },
    devtool: 'inline-source-map',
    plugins: [new _npmInstallWebpackPlugin2.default({
      dev: false,
      peerDependencies: true,
      quiet: true
    }), new _webpack2.default.HotModuleReplacementPlugin()]
  });
  if (enableHTMLPlugin) {
    var options = Object.assign({}, {
      filename: 'index.html',
      template: './index.html'
    }, enableHTMLPlugin);
    config.plugins.unshift(new _htmlWebpackPlugin2.default(options));
  }
  if (Array.isArray(vendor)) {
    config.plugins.unshift(new _autodllWebpackPlugin2.default({
      debug: true,
      inject: true,
      filename: '[name].js',
      entry: {
        vendor: vendor
      }
    }));
  }
  return config;
};
exports.default = {
  devConfig: getInitDevConfig({}),
  getInitDevConfig
};