import commonConfig from '../common';
import defaultConfig from '../default';
import { resolve } from 'path';
import webpack from 'webpack';
import merge from 'webpack-merge';
import NpmInstallWebpackPlugin from 'npm-install-webpack-plugin';
import HtmlWebpackPlugin from 'html-webpack-plugin';
import AutoDllPlugin from 'autodll-webpack-plugin';
let getInitDevConfig = ({
  root,
  srcPath,
  distPath,
  vendor,
  enableHTMLPlugin,
  devServer
}) => {
  root = root || defaultConfig.root;
  srcPath = srcPath || defaultConfig.srcPath;
  distPath = distPath || defaultConfig.distPath;
  enableHTMLPlugin = enableHTMLPlugin || defaultConfig.enableHTMLPlugin;
  devServer = Object.assign({}, defaultConfig.devServer, devServer);
  let config = merge(commonConfig, {
    //mode: 'development',
    context: resolve(root, srcPath),
    entry: {
      app: './index.js'
    },
    output: {
      filename: '[name]-[id].js',
      path: resolve(root, distPath)
    },
    devServer: devServer,
    module: {
      rules: [{
        test:/\.js$/,
        loader: 'babel-loader',
        exclude: /node_modules/
      },
      {
        test:/\.css$/,
        exclude: /node_modules/,
        use: [{
          loader: 'style-loader',
          options: {
            sourceMap: true
          }
        }, {
          loader: 'css-loader',
          options: {
            importLoaders: 0,
            modules: true,
            localIdentName: '[name]_[local]'
          }
        }]
      },{
        //引入的css包不使用css modules
        test: /(?=node_modules).*\.css$/,
        use: [
          'style-loader',
          'css-loader'
        ]
      },{
        test: /\.(jpe?g|png|gif|svg|woff|woff2|eot|otf|ttf)$/i,
        use: [{
          loader: 'file-loader',
          options:{
            name: '[path]/[name].[ext]'
          }
        }]
      }
      ]
    },
    devtool: 'inline-source-map',
    plugins: [
      new NpmInstallWebpackPlugin({
        dev: false,
        peerDependencies: true,
        quiet: true
      }),
      new webpack.HotModuleReplacementPlugin()
    ]
  });
  if(enableHTMLPlugin){
    let options = Object.assign({}, {
      filename: 'index.html',
      template: './index.html'
    }, enableHTMLPlugin);
    config.plugins.unshift(
      new HtmlWebpackPlugin(options)
    );
  }
  if(Array.isArray(vendor)){
    config.plugins.unshift(
      new AutoDllPlugin({
        debug: true,
        inject: true,
        filename: '[name].js',
        entry: {
          vendor: vendor
        }
      })
    );
  }
  return config;
};
export default {
  devConfig: getInitDevConfig({}),
  getInitDevConfig
};