import commonConfig from '../common';
import defaultConfig from '../default';
import { resolve } from 'path';
import webpack from 'webpack';
import merge from 'webpack-merge';
import HtmlWebpackPlugin from 'html-webpack-plugin';
import AutoDllPlugin from 'autodll-webpack-plugin';
import Clean from 'clean-webpack-plugin';
import ExtractTextWebpackPlugin from 'extract-text-webpack-plugin';
import OptimizeCSSAssets from 'optimize-css-assets-webpack-plugin';
let packageCss = new ExtractTextWebpackPlugin('styles/package_[hash].css');
let selfCss = new ExtractTextWebpackPlugin('styles/self_[hash].css');
let getInitProdConfig = ({
  root,
  srcPath,
  distPath,
  publicPath,
  vendor,
  enableHTMLPlugin
}) => {
  root = root || defaultConfig.root;
  srcPath = srcPath || defaultConfig.srcPath;
  distPath = distPath || defaultConfig.distPath;
  publicPath = publicPath || defaultConfig.publicPath;
  enableHTMLPlugin = enableHTMLPlugin || defaultConfig.enableHTMLPlugin;
  let config = merge(commonConfig, {
    context: resolve(root, srcPath),
    entry: {
      app: './index.js'
    },
    output: {
      filename: 'scripts/init/[name]-[hash].js',
      chunkFilename: 'scripts/chunks/[name]-[chunkhash].js',
      publicPath: publicPath,
      path: resolve(root, distPath)
    },
    module: {
      rules: [{
        test:/\.js$/,
        loader: 'babel-loader',
        exclude: /node_modules/
      },{
        test: /\.css$/,
        exclude:/node_modules/,
        use: selfCss.extract({
          fallback: 'style-loader',
          use: [{
            loader: 'css-loader',
            options: {
              sourceMap: true,
              modules: true,
              importLoaders: 0,
              localIdentName: '[name]_[local]'
            }
          }]
        })
      },{
        test:/\.css$/,
        include: /node_modules/,
        use: packageCss.extract(['style-loader', 'css-loader'])
      },{
        test: /\.(jpe?g|png|gif|svg|woff|woff2|eot|otf|ttf)$/i,
        use: [
          {
            loader: 'file-loader',
            options: {
              name: '[path]/[name]-[hash].[ext]',
              outputPath: 'assets/'
            }
          }
        ]
      }]
    },
    devtool: 'source-map',
    plugins: [
      new Clean(['**/*.*'], {
        root: resolve(root, distPath)
      }),
      new webpack.DefinePlugin({
        'process.env.NODE_ENV': JSON.stringify('production')
      }),
      packageCss,
      selfCss,
      new OptimizeCSSAssets(),
      new webpack.optimize.UglifyJsPlugin({
        parallel: true
      })
    ]
  });
  if(enableHTMLPlugin){
    let options = Object.assign({}, {
      filename: 'index.html',
      template: './index.html'
    }, enableHTMLPlugin);
    config.plugins.unshift(
      new HtmlWebpackPlugin(options)
    );
  }
  if(Array.isArray(vendor)){
    config.plugins.unshift(
      new AutoDllPlugin({
        filename: '[name]_[hash].js',
        inject: true,
        entry: {
          vendor: vendor
        },
        output: {
          publicPath: publicPath
        },
        plugins: [
          new webpack.DefinePlugin({
            'process.env.NODE_ENV': JSON.stringify('production')
          }),
          new webpack.optimize.UglifyJsPlugin()
        ]
      })
    );
  }
  return config;
};
export default{
  prodConfig: getInitProdConfig({}),
  getInitProdConfig
};